@@ -33,6 +33,7 @@
 #  define KEMOTICONS_DECL_DEPRECATED_NO_EXPORT KEMOTICONS_NO_EXPORT KEMOTICONS_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KEMOTICONS_NO_DEPRECATED
 #    define KEMOTICONS_NO_DEPRECATED
@@ -84,7 +85,7 @@
 #define KEMOTICONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KEMOTICONS_NO_DEPRECATED
-#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
 #endif
 #ifdef KEMOTICONS_NO_DEPRECATED_WARNINGS
 #  define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +95,7 @@
 #  ifdef KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x57400
 #  endif
 #endif
 
